@@ -1,5 +1,5 @@
 """Exception classes."""
-import requests
+import urllib3
 
 
 class MyHomeException(Exception):
@@ -9,7 +9,7 @@ class MyHomeException(Exception):
 class LoginFailure(MyHomeException):
     """Login failure."""
 
-    def __init__(self, resp: requests.Response, message: str):
+    def __init__(self, resp: urllib3.response.HTTPResponse, message: str):
         """Construct exception."""
         self.resp = resp
         super().__init__(message)
@@ -18,7 +18,7 @@ class LoginFailure(MyHomeException):
 class RemoteAccessDenied(LoginFailure):
     """Remote access is not permitted for given user."""
 
-    def __init__(self, resp: requests.Response):
+    def __init__(self, resp: urllib3.response.Response):
         """Construct exception."""
         super().__init__(resp, "Remote access denied for user")
 
@@ -26,7 +26,7 @@ class RemoteAccessDenied(LoginFailure):
 class UnknownLoginFailure(LoginFailure):
     """Unknown login failure."""
 
-    def __init__(self, resp: requests.Response):
+    def __init__(self, resp: urllib3.response.Response):
         """Construct exception."""
         super().__init__(resp, "An unknown issue has occurred during login")
 
@@ -34,6 +34,6 @@ class UnknownLoginFailure(LoginFailure):
 class LoginDenied(LoginFailure):
     """Username and/or password incorrect."""
 
-    def __init__(self, resp: requests.Response):
+    def __init__(self, resp: urllib3.response.Response):
         """Construct exception."""
         super().__init__(resp, "Username and/or password incorrect")
