@@ -1,13 +1,11 @@
 """Thermostat support."""
 import typing
 
-from ..gen import (  # type: ignore
-    DefaultApi,
-    ObjectInfo,
-    ObjectValueThermostat,
-    Room,
-    Zone,
-)
+from .._gen.api.default_api import DefaultApi
+from .._gen.model.object_info import ObjectInfo
+from .._gen.model.object_value_thermostat import ObjectValueThermostat
+from .._gen.model.room import Room
+from .._gen.model.zone import Zone
 from .base import BaseObject
 
 
